# Generated by roxygen2: do not edit by hand

export(ck_apply_grid)
export(ck_available)
export(ck_branas)
export(ck_browse)
export(ck_catalogue)
export(ck_compute)
export(ck_convert_temp)
export(ck_cooling_degree_days)
export(ck_csdi)
export(ck_cwa)
export(ck_cwd)
export(ck_cwf)
export(ck_cwm)
export(ck_cwn)
export(ck_diurnal_range)
export(ck_dry_days)
export(ck_ehf)
export(ck_etccdi_27)
export(ck_fire_danger)
export(ck_first_frost)
export(ck_from_netcdf)
export(ck_frost_days)
export(ck_growing_degree_days)
export(ck_growing_season)
export(ck_heat_index)
export(ck_heating_degree_days)
export(ck_heavy_precip)
export(ck_huglin)
export(ck_humidex)
export(ck_hwa)
export(ck_hwd)
export(ck_hwf)
export(ck_hwm)
export(ck_hwn)
export(ck_ice_days)
export(ck_last_frost)
export(ck_max_1day_precip)
export(ck_max_5day_precip)
export(ck_metadata)
export(ck_pet)
export(ck_pet_pm)
export(ck_precip_intensity)
export(ck_r95p)
export(ck_r99p)
export(ck_spei)
export(ck_spi)
export(ck_summer_days)
export(ck_tn10p)
export(ck_tn90p)
export(ck_tnn)
export(ck_tnx)
export(ck_total_precip)
export(ck_tropical_nights)
export(ck_tx10p)
export(ck_tx90p)
export(ck_txn)
export(ck_txx)
export(ck_very_heavy_precip)
export(ck_warm_spell)
export(ck_wet_days)
export(ck_wind_chill)
export(ck_winkler)
export(ck_wsdi)
export(clear_cache)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(tools,R_user_dir)
