% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/comfort.R
\name{ck_heat_index}
\alias{ck_heat_index}
\title{Heat Index}
\usage{
ck_heat_index(tavg, humidity)
}
\arguments{
\item{tavg}{Numeric vector of temperatures (degrees C).}

\item{humidity}{Numeric vector of relative humidity (percent, 0-100).}
}
\value{
A data frame with columns \code{value}, \code{index}, and \code{unit}.
}
\description{
Compute the heat index (apparent temperature) using the Rothfusz
regression equation used by the US National Weather Service.
}
\examples{
ck_heat_index(tavg = c(30, 35, 40), humidity = c(60, 70, 50))
}
\references{
Rothfusz, L. P. (1990). The heat index equation.
NWS Technical Attachment SR 90-23.
}
